useful StringExt utilities for crate::str_concat macros
Modules
- Base64 padding
Structs
- Base64 inner string
- Number to string
- Simple wrapper over
const_hex::Bufferthat implementsStringExtT. - A string with extended utilities
Enums
- Hex string with fixed length.
Traits
- Trait for removing the separator from the end of the string
- Trait for pushing any value that can be converted into str to
StringExt