pub struct NumStr<const B: u8 = 10, const U: bool = false, const R: usize = 0, const M: usize = 0, T = usize>(/* private fields */);Expand description
Number to string
Generic
-
B: the base of the number, should be within the range2..=16. Default is 10. -
U: whether to use uppercase for hex. Default is lowercase (false) -
R: the resize length of the string. The overflow part will be truncated, and the insufficient part will be filled with ‘0’. Default is 0, or no resize. -
M: the minimum length of the string, if the length of the string is less thanM, fill with ‘0’. Default is 0, or no minimum. For signed numberMwill be ignored. -
T: the underlying type of the number. Default isusize.
Panic
- Invalid base (== 0 or > 16)
Implementations
Sourceimpl<T> NumStr<10, false, 0, 0, T>
impl<T> NumStr<10, false, 0, 0, T>
Sourcepub fn new_default(inner: T) -> Self
pub fn new_default(inner: T) -> Self
Sourceimpl<const B: u8, const U: bool, const R: usize, const M: usize, T> NumStr<B, U, R, M, T>
impl<const B: u8, const U: bool, const R: usize, const M: usize, T> NumStr<B, U, R, M, T>
Sourcepub fn hexadecimal(self) -> NumStr<16, U, R, M, T>
pub fn hexadecimal(self) -> NumStr<16, U, R, M, T>
Convert to hexadecimal representation.
Sourcepub fn set_custom_base<const NB: u8>(self) -> NumStr<NB, U, R, M, T>
pub fn set_custom_base<const NB: u8>(self) -> NumStr<NB, U, R, M, T>
Set custom base.
The valid range is 2..=16
Sourcepub fn set_uppercase<const NU: bool>(self) -> NumStr<B, NU, R, M, T>
pub fn set_uppercase<const NU: bool>(self) -> NumStr<B, NU, R, M, T>
Set uppercase / lowercase of the number.
Default is lowercase
Note: only works for base > 10
Sourcepub fn set_resize_len<const NR: usize>(self) -> NumStr<B, U, NR, M, T>
pub fn set_resize_len<const NR: usize>(self) -> NumStr<B, U, NR, M, T>
Set whether to resize the string to len length.
The overflow part will be truncated, and the insufficient part will be filled with ‘0’
Default is not resize
Note: see Vec::resize for details
Sourcepub fn set_minimum_len<const NM: usize>(self) -> NumStr<B, U, R, NM, T>
pub fn set_minimum_len<const NM: usize>(self) -> NumStr<B, U, R, NM, T>
Set the minimum length of the string.
The insufficient part will be filled with ‘0’.
Default is not minimum
Note: if set Self::should_resize, the minimum length will be ignored