pub trait Config {
// Required method
fn encode_padding(&self) -> bool;
}Expand description
The minimal level of configuration that engines must support.
Required Methods
Sourcefn encode_padding(&self) -> bool
fn encode_padding(&self) -> bool
Returns true if padding should be added after the encoded output.
Padding is added outside the engine’s encode() since the engine may be used to encode only a chunk of the overall output, so it can’t always know when the output is “done” and would therefore need padding (if configured).
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".